==> TuxGuitar-0.8-src.tar.gz: TuxGuitar-0.8-src/src/org/herac/tuxguitar/gui/actions/note/InsertNoteAction.java <==
/*
 * Created on 17-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.actions.note;

import org.eclipse.swt.events.TypedEvent;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.actions.Action;
import org.herac.tuxguitar.gui.tab.Caret;
import org.herac.tuxguitar.gui.tab.MeasureComponent;
import org.herac.tuxguitar.gui.undo.undoables.component.UndoableComponentGeneric;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class InsertNoteAction extends Action{
    public static final String NAME = "INSERT_NOTE";
    
    public InsertNoteAction(TablatureEditor tablatureEditor) {
        super(NAME,tablatureEditor);       
    }

    public boolean doAction(TypedEvent e) {
        //comienza el undoable
        UndoableComponentGeneric undoable = UndoableComponentGeneric.startUndo(); 	
    	
        Caret caret = getEditor().getTablature().getCaret();
        MeasureComponent component = caret.getSelectedComponent();
        if(component != null){
            long start = component.getStart();
            long length = component.getDuration().getTime();
            getSongManager().getMeasureManager().moveComponents(caret.getMeasureCoords().getMeasure(),start,length);
        }        
        
        //termia el undoable
        getEditor().getUndoManager().addEdit(undoable.endUndo());           
        
        updateTablature();   
        return true;
    }
    
    protected void updateTablature() {
        fireUpdate(getEditor().getTablature().getCaret().getMeasureCoords().getMeasure().getNumber());        
        redraw();
    }


}

==> TuxGuitar-0.9-src.tar.gz: TuxGuitar-0.9-src/src/org/herac/tuxguitar/gui/actions/note/InsertNoteAction.java <==
/*
 * Created on 17-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.actions.note;

import org.eclipse.swt.events.TypedEvent;
import org.herac.tuxguitar.gui.actions.Action;
import org.herac.tuxguitar.gui.editors.TablatureEditor;
import org.herac.tuxguitar.gui.editors.tab.Caret;
import org.herac.tuxguitar.gui.editors.tab.MeasureComponent;
import org.herac.tuxguitar.gui.undo.undoables.measure.UndoableMeasureGeneric;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class InsertNoteAction extends Action{
    public static final String NAME = "action.note.general.insert";
    
    public InsertNoteAction(TablatureEditor tablatureEditor) {
        super(NAME,tablatureEditor);       
    }

    public boolean doAction(TypedEvent e) {
        //comienza el undoable
        UndoableMeasureGeneric undoable = UndoableMeasureGeneric.startUndo(); 	
    	
        Caret caret = getEditor().getTablature().getCaret();
        MeasureComponent component = caret.getSelectedComponent();
        if(component != null){
            long start = component.getStart();
            long length = component.getDuration().getTime();
            getSongManager().getMeasureManager().moveComponents(caret.getMeasureCoords().getMeasure(),start,length);
        }        
        
        //termia el undoable
        getEditor().getUndoManager().addEdit(undoable.endUndo());           
        
        updateTablature();   
        return true;
    }
    
    protected void updateTablature() {
        fireUpdate(getEditor().getTablature().getCaret().getMeasureCoords().getMeasure().getNumber());        
        redraw();
    }


}
